@@ -181,7 +181,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = contacts
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return contacts
 
@@ -213,7 +213,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = alarms
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return alarms
 
@@ -271,7 +271,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = watch_location
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return watch_location
 
@@ -302,7 +302,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = asktrack_raw
             if dataOk is WatchOnlineStatus.UNKNOWN:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return asktrack_raw.value
 
@@ -339,13 +339,15 @@ class PyXploraApi(PyXplora):
                             "data_text": chat.data.text,
                             "data_sender_name": chat.data.sender_name,
                             "create": datetime.fromtimestamp(chat.create).strftime("%Y-%m-%d %H:%M:%S"),
+                            "delete_flag": chat.data.delete_flag,
+                            "emoticon_id": chat.data.emoticon_id,
                         }
                     )
             except Error as error:
                 _LOGGER.debug(error)
             dataOk = chats
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return chats
 
@@ -360,20 +362,23 @@ class PyXploraApi(PyXplora):
             try:
                 chats: Chats = Chats.from_dict(self._gqlHandler.chats(wuid, offset, limit, msgId))
 
-                oldChatList: list[SimpleChat] = chats.chatsNew.list
-                newChatList: list[SimpleChat] = []
-                for chat in oldChatList:
-                    chat.data.emoticon_id = Emoji["M%s" % chat.data.emoticon_id].value
-                    if show_del_msg:
-                        newChatList.append(chat)
-                    elif chat.data.delete_flag == 0:
-                        newChatList.append(chat)
-                _chatsNew = ChatsNew(newChatList).to_dict()
+                chatsNew: ChatsNew = ChatsNew.from_dict(chats.chatsNew)
+
+                oldChatList: list[SimpleChat] = chatsNew.get_list()
+                if oldChatList:
+                    newChatList: list[SimpleChat] = []
+                    for chat in oldChatList:
+                        chat.data.emoticon_id = Emoji["M%s" % chat.data.emoticon_id].value
+                        if show_del_msg:
+                            newChatList.append(chat)
+                        elif chat.data.delete_flag == 0:
+                            newChatList.append(chat)
+                    _chatsNew = ChatsNew(newChatList).to_dict()
             except Error as error:
                 _LOGGER.debug(error)
             dataOk = _chatsNew
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return _chatsNew
 
@@ -436,7 +441,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = safe_zones
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return safe_zones
 
@@ -475,7 +480,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = school_silent_mode
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return school_silent_mode
 
@@ -495,7 +500,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return bool(_raw)
 
@@ -515,7 +520,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return bool(_raw)
 
@@ -547,7 +552,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return bool(_raw)
 
@@ -567,7 +572,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return bool(_raw)
 
@@ -633,7 +638,7 @@ class PyXploraApi(PyXplora):
                 _LOGGER.debug(error)
             dataOk = watches
             if not dataOk:
-                self._logoff()
+                # self._logoff()
                 self.delay(self.retryDelay)
         return watches
 
